@@ -25,21 +25,19 @@ import (
 	corev1 "k8s.io/api/core/v1"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 	"k8s.io/apimachinery/pkg/runtime"
-	"k8s.io/apimachinery/pkg/util/sets"
 
 	"knative.dev/pkg/ptr"
 	net "knative.dev/serving/pkg/apis/networking"
 	"knative.dev/serving/pkg/apis/serving"
 	v1 "knative.dev/serving/pkg/apis/serving/v1"
-	"knative.dev/serving/pkg/apis/serving/v1alpha1"
 	fakeclientset "knative.dev/serving/pkg/client/clientset/versioned/fake"
 	informers "knative.dev/serving/pkg/client/informers/externalversions"
-	listers "knative.dev/serving/pkg/client/listers/serving/v1alpha1"
+	listers "knative.dev/serving/pkg/client/listers/serving/v1"
 	"knative.dev/serving/pkg/gc"
 	"knative.dev/serving/pkg/network"
 	"knative.dev/serving/pkg/reconciler/route/config"
 	"knative.dev/serving/pkg/reconciler/route/domains"
-	. "knative.dev/serving/pkg/testing/v1alpha1"
+	. "knative.dev/serving/pkg/testing/v1"
 )
 
 const testNamespace string = "test"
@@ -48,36 +46,36 @@ const testNamespace string = "test"
 // Tests should not modify these objects.
 var (
 	// These are objects never inserted.
-	missingConfig *v1alpha1.Configuration
-	missingRev    *v1alpha1.Revision
+	missingConfig *v1.Configuration
+	missingRev    *v1.Revision
 
 	// emptyConfig never has any revision.
-	emptyConfig *v1alpha1.Configuration
+	emptyConfig *v1.Configuration
 
 	// revDeletedConfig has a Ready revision but was deleted.
-	revDeletedConfig *v1alpha1.Configuration
+	revDeletedConfig *v1.Configuration
 
 	// unreadyConfig only has unreadyRev, and it's not ready.
-	unreadyConfig *v1alpha1.Configuration
-	unreadyRev    *v1alpha1.Revision
+	unreadyConfig *v1.Configuration
+	unreadyRev    *v1.Revision
 
 	// failedConfig only has failedRev, and it fails to be ready.
-	failedConfig *v1alpha1.Configuration
-	failedRev    *v1alpha1.Revision
+	failedConfig *v1.Configuration
+	failedRev    *v1.Revision
 
 	// inactiveConfig only has inactiveRevision, and it's not active.
-	inactiveConfig *v1alpha1.Configuration
-	inactiveRev    *v1alpha1.Revision
+	inactiveConfig *v1.Configuration
+	inactiveRev    *v1.Revision
 
 	// goodConfig has two good revisions: goodOldRev and goodNewRev
-	goodConfig *v1alpha1.Configuration
-	goodOldRev *v1alpha1.Revision
-	goodNewRev *v1alpha1.Revision
+	goodConfig *v1.Configuration
+	goodOldRev *v1.Revision
+	goodNewRev *v1.Revision
 
 	// niceConfig has two good revisions: niceOldRev and niceNewRev
-	niceConfig *v1alpha1.Configuration
-	niceOldRev *v1alpha1.Revision
-	niceNewRev *v1alpha1.Revision
+	niceConfig *v1.Configuration
+	niceOldRev *v1.Revision
+	niceNewRev *v1.Revision
 
 	configLister listers.ConfigurationLister
 	revLister    listers.RevisionLister
@@ -96,9 +94,9 @@ func setUp() {
 	servingClient := fakeclientset.NewSimpleClientset()
 
 	servingInformer := informers.NewSharedInformerFactory(servingClient, 0)
-	configInformer := servingInformer.Serving().V1alpha1().Configurations()
+	configInformer := servingInformer.Serving().V1().Configurations()
 	configLister = configInformer.Lister()
-	revInformer := servingInformer.Serving().V1alpha1().Revisions()
+	revInformer := servingInformer.Serving().V1().Revisions()
 	revLister = revInformer.Lister()
 
 	// Add these test objects to the informers.
@@ -114,9 +112,9 @@ func setUp() {
 
 	for _, obj := range objs {
 		switch o := obj.(type) {
-		case *v1alpha1.Configuration:
+		case *v1.Configuration:
 			configInformer.Informer().GetIndexer().Add(o)
-		case *v1alpha1.Revision:
+		case *v1.Revision:
 			revInformer.Informer().GetIndexer().Add(o)
 		}
 	}
@@ -126,11 +124,9 @@ func setUp() {
 
 // The vanilla use case of 100% directing to latest ready revision of a single configuration.
 func TestBuildTrafficConfiguration_Vanilla(t *testing.T) {
-	tts := v1alpha1.TrafficTarget{
-		TrafficTarget: v1.TrafficTarget{
-			ConfigurationName: goodConfig.Name,
-			Percent:           ptr.Int64(100),
-		},
+	tts := v1.TrafficTarget{
+		ConfigurationName: goodConfig.Name,
+		Percent:           ptr.Int64(100),
 	}
 
 	expected := &Config{
@@ -156,10 +152,10 @@ func TestBuildTrafficConfiguration_Vanilla(t *testing.T) {
 			Active:   true,
 			Protocol: net.ProtocolH2C,
 		}},
-		Configurations: map[string]*v1alpha1.Configuration{
+		Configurations: map[string]*v1.Configuration{
 			goodConfig.Name: goodConfig,
 		},
-		Revisions: map[string]*v1alpha1.Revision{
+		Revisions: map[string]*v1.Revision{
 			goodNewRev.Name: goodNewRev,
 		},
 	}
@@ -170,16 +166,14 @@ func TestBuildTrafficConfiguration_Vanilla(t *testing.T) {
 	}
 }
 
-func testRouteWithTrafficTargets(trafficTarget RouteOption) *v1alpha1.Route {
+func testRouteWithTrafficTargets(trafficTarget RouteOption) *v1.Route {
 	return Route(testNamespace, "test-route", WithRouteLabel(map[string]string{"route": "test-route"}), trafficTarget)
 }
 
 func TestBuildTrafficConfiguration_NoNameRevision(t *testing.T) {
-	tts := v1alpha1.TrafficTarget{
-		TrafficTarget: v1.TrafficTarget{
-			RevisionName: goodNewRev.Name,
-			Percent:      ptr.Int64(100),
-		},
+	tts := v1.TrafficTarget{
+		RevisionName: goodNewRev.Name,
+		Percent:      ptr.Int64(100),
 	}
 	expected := &Config{
 		Targets: map[string]RevisionTargets{
@@ -204,8 +198,8 @@ func TestBuildTrafficConfiguration_NoNameRevision(t *testing.T) {
 			Active:   true,
 			Protocol: net.ProtocolH2C,
 		}},
-		Configurations: map[string]*v1alpha1.Configuration{goodConfig.Name: goodConfig},
-		Revisions:      map[string]*v1alpha1.Revision{goodNewRev.Name: goodNewRev},
+		Configurations: map[string]*v1.Configuration{goodConfig.Name: goodConfig},
+		Revisions:      map[string]*v1.Revision{goodNewRev.Name: goodNewRev},
 	}
 	if tc, err := BuildTrafficConfiguration(configLister, revLister, testRouteWithTrafficTargets(WithSpecTraffic(tts))); err != nil {
 		t.Errorf("Unexpected error %v", err)
@@ -216,11 +210,9 @@ func TestBuildTrafficConfiguration_NoNameRevision(t *testing.T) {
 
 // The vanilla use case of 100% directing to latest revision of an inactive configuration.
 func TestBuildTrafficConfiguration_VanillaScaledToZero(t *testing.T) {
-	tts := v1alpha1.TrafficTarget{
-		TrafficTarget: v1.TrafficTarget{
-			ConfigurationName: inactiveConfig.Name,
-			Percent:           ptr.Int64(100),
-		},
+	tts := v1.TrafficTarget{
+		ConfigurationName: inactiveConfig.Name,
+		Percent:           ptr.Int64(100),
 	}
 	expected := &Config{
 		Targets: map[string]RevisionTargets{
@@ -245,10 +237,10 @@ func TestBuildTrafficConfiguration_VanillaScaledToZero(t *testing.T) {
 			Active:   false,
 			Protocol: net.ProtocolHTTP1,
 		}},
-		Configurations: map[string]*v1alpha1.Configuration{
+		Configurations: map[string]*v1.Configuration{
 			inactiveConfig.Name: inactiveConfig,
 		},
-		Revisions: map[string]*v1alpha1.Revision{
+		Revisions: map[string]*v1.Revision{
 			inactiveRev.Name: inactiveRev,
 		},
 	}
@@ -302,25 +294,21 @@ func TestBuildTrafficConfiguration_TwoConfigs(t *testing.T) {
 			Active:   true,
 			Protocol: net.ProtocolH2C,
 		}},
-		Configurations: map[string]*v1alpha1.Configuration{
+		Configurations: map[string]*v1.Configuration{
 			goodConfig.Name: goodConfig,
 			niceConfig.Name: niceConfig,
 		},
-		Revisions: map[string]*v1alpha1.Revision{
+		Revisions: map[string]*v1.Revision{
 			goodNewRev.Name: goodNewRev,
 			niceNewRev.Name: niceNewRev,
 		},
 	}
-	if tc, err := BuildTrafficConfiguration(configLister, revLister, testRouteWithTrafficTargets(WithSpecTraffic(v1alpha1.TrafficTarget{
-		TrafficTarget: v1.TrafficTarget{
-			ConfigurationName: niceConfig.Name,
-			Percent:           ptr.Int64(90),
-		},
-	}, v1alpha1.TrafficTarget{
-		TrafficTarget: v1.TrafficTarget{
-			ConfigurationName: goodConfig.Name,
-			Percent:           ptr.Int64(10),
-		},
+	if tc, err := BuildTrafficConfiguration(configLister, revLister, testRouteWithTrafficTargets(WithSpecTraffic(v1.TrafficTarget{
+		ConfigurationName: niceConfig.Name,
+		Percent:           ptr.Int64(90),
+	}, v1.TrafficTarget{
+		ConfigurationName: goodConfig.Name,
+		Percent:           ptr.Int64(10),
 	}))); err != nil {
 		t.Errorf("Unexpected error %v", err)
 	} else if got, want := tc, expected; !cmp.Equal(want, got, cmpOpts...) {
@@ -371,24 +359,20 @@ func TestBuildTrafficConfiguration_Canary(t *testing.T) {
 			Active:   true,
 			Protocol: net.ProtocolH2C,
 		}},
-		Configurations: map[string]*v1alpha1.Configuration{
+		Configurations: map[string]*v1.Configuration{
 			goodConfig.Name: goodConfig,
 		},
-		Revisions: map[string]*v1alpha1.Revision{
+		Revisions: map[string]*v1.Revision{
 			goodOldRev.Name: goodOldRev,
 			goodNewRev.Name: goodNewRev,
 		},
 	}
-	if tc, err := BuildTrafficConfiguration(configLister, revLister, testRouteWithTrafficTargets(WithSpecTraffic(v1alpha1.TrafficTarget{
-		TrafficTarget: v1.TrafficTarget{
-			RevisionName: goodOldRev.Name,
-			Percent:      ptr.Int64(90),
-		},
-	}, v1alpha1.TrafficTarget{
-		TrafficTarget: v1.TrafficTarget{
-			ConfigurationName: goodConfig.Name,
-			Percent:           ptr.Int64(10),
-		},
+	if tc, err := BuildTrafficConfiguration(configLister, revLister, testRouteWithTrafficTargets(WithSpecTraffic(v1.TrafficTarget{
+		RevisionName: goodOldRev.Name,
+		Percent:      ptr.Int64(90),
+	}, v1.TrafficTarget{
+		ConfigurationName: goodConfig.Name,
+		Percent:           ptr.Int64(10),
 	}))); err != nil {
 		t.Errorf("Unexpected error %v", err)
 	} else if got, want := tc, expected; !cmp.Equal(want, got, cmpOpts...) {
@@ -486,32 +470,26 @@ func TestBuildTrafficConfiguration_Consolidated(t *testing.T) {
 			Active:   true,
 			Protocol: net.ProtocolH2C,
 		}},
-		Configurations: map[string]*v1alpha1.Configuration{
+		Configurations: map[string]*v1.Configuration{
 			goodConfig.Name: goodConfig,
 		},
-		Revisions: map[string]*v1alpha1.Revision{
+		Revisions: map[string]*v1.Revision{
 			goodOldRev.Name: goodOldRev,
 			goodNewRev.Name: goodNewRev,
 		},
 	}
-	if tc, err := BuildTrafficConfiguration(configLister, revLister, testRouteWithTrafficTargets(WithSpecTraffic(v1alpha1.TrafficTarget{
-		TrafficTarget: v1.TrafficTarget{
-			Tag:          "one",
-			RevisionName: goodOldRev.Name,
-			Percent:      ptr.Int64(49),
-		},
-	}, v1alpha1.TrafficTarget{
-		TrafficTarget: v1.TrafficTarget{
-			Tag:          "two",
-			RevisionName: goodNewRev.Name,
-			Percent:      ptr.Int64(50),
-		},
-	}, v1alpha1.TrafficTarget{
-		TrafficTarget: v1.TrafficTarget{
-			Tag:               "also-two",
-			ConfigurationName: goodConfig.Name,
-			Percent:           ptr.Int64(1),
-		},
+	if tc, err := BuildTrafficConfiguration(configLister, revLister, testRouteWithTrafficTargets(WithSpecTraffic(v1.TrafficTarget{
+		Tag:          "one",
+		RevisionName: goodOldRev.Name,
+		Percent:      ptr.Int64(49),
+	}, v1.TrafficTarget{
+		Tag:          "two",
+		RevisionName: goodNewRev.Name,
+		Percent:      ptr.Int64(50),
+	}, v1.TrafficTarget{
+		Tag:               "also-two",
+		ConfigurationName: goodConfig.Name,
+		Percent:           ptr.Int64(1),
 	}))); err != nil {
 		t.Errorf("Unexpected error %v", err)
 	} else if got, want := tc, expected; !cmp.Equal(want, got, cmpOpts...) {
@@ -562,24 +540,20 @@ func TestBuildTrafficConfiguration_TwoFixedRevisions(t *testing.T) {
 			Active:   true,
 			Protocol: net.ProtocolH2C,
 		}},
-		Configurations: map[string]*v1alpha1.Configuration{
+		Configurations: map[string]*v1.Configuration{
 			goodConfig.Name: goodConfig,
 		},
-		Revisions: map[string]*v1alpha1.Revision{
+		Revisions: map[string]*v1.Revision{
 			goodNewRev.Name: goodNewRev,
 			goodOldRev.Name: goodOldRev,
 		},
 	}
-	if tc, err := BuildTrafficConfiguration(configLister, revLister, testRouteWithTrafficTargets(WithSpecTraffic(v1alpha1.TrafficTarget{
-		TrafficTarget: v1.TrafficTarget{
-			RevisionName: goodOldRev.Name,
-			Percent:      ptr.Int64(90),
-		},
-	}, v1alpha1.TrafficTarget{
-		TrafficTarget: v1.TrafficTarget{
-			RevisionName: goodNewRev.Name,
-			Percent:      ptr.Int64(10),
-		},
+	if tc, err := BuildTrafficConfiguration(configLister, revLister, testRouteWithTrafficTargets(WithSpecTraffic(v1.TrafficTarget{
+		RevisionName: goodOldRev.Name,
+		Percent:      ptr.Int64(90),
+	}, v1.TrafficTarget{
+		RevisionName: goodNewRev.Name,
+		Percent:      ptr.Int64(10),
 	}))); err != nil {
 		t.Errorf("Unexpected error %v", err)
 	} else if got, want := tc, expected; !cmp.Equal(want, got, cmpOpts...) {
@@ -630,25 +604,21 @@ func TestBuildTrafficConfiguration_TwoFixedRevisionsFromTwoConfigurations(t *tes
 			Active:   true,
 			Protocol: net.ProtocolH2C,
 		}},
-		Configurations: map[string]*v1alpha1.Configuration{
+		Configurations: map[string]*v1.Configuration{
 			goodConfig.Name: goodConfig,
 			niceConfig.Name: niceConfig,
 		},
-		Revisions: map[string]*v1alpha1.Revision{
+		Revisions: map[string]*v1.Revision{
 			goodNewRev.Name: goodNewRev,
 			niceNewRev.Name: niceNewRev,
 		},
 	}
-	if tc, err := BuildTrafficConfiguration(configLister, revLister, testRouteWithTrafficTargets(WithSpecTraffic(v1alpha1.TrafficTarget{
-		TrafficTarget: v1.TrafficTarget{
-			RevisionName: goodNewRev.Name,
-			Percent:      ptr.Int64(40),
-		},
-	}, v1alpha1.TrafficTarget{
-		TrafficTarget: v1.TrafficTarget{
-			RevisionName: niceNewRev.Name,
-			Percent:      ptr.Int64(60),
-		},
+	if tc, err := BuildTrafficConfiguration(configLister, revLister, testRouteWithTrafficTargets(WithSpecTraffic(v1.TrafficTarget{
+		RevisionName: goodNewRev.Name,
+		Percent:      ptr.Int64(40),
+	}, v1.TrafficTarget{
+		RevisionName: niceNewRev.Name,
+		Percent:      ptr.Int64(60),
 	}))); err != nil {
 		t.Errorf("Unexpected error %v", err)
 	} else if got, want := tc, expected; !cmp.Equal(want, got, cmpOpts...) {
@@ -739,31 +709,25 @@ func TestBuildTrafficConfiguration_Preliminary(t *testing.T) {
 			Active:   true,
 			Protocol: net.ProtocolH2C,
 		}},
-		Configurations: map[string]*v1alpha1.Configuration{
+		Configurations: map[string]*v1.Configuration{
 			goodConfig.Name: goodConfig,
 			niceConfig.Name: niceConfig,
 		},
-		Revisions: map[string]*v1alpha1.Revision{
+		Revisions: map[string]*v1.Revision{
 			goodOldRev.Name: goodOldRev,
 			goodNewRev.Name: goodNewRev,
 			niceNewRev.Name: niceNewRev,
 		},
 	}
-	if tc, err := BuildTrafficConfiguration(configLister, revLister, testRouteWithTrafficTargets(WithSpecTraffic(v1alpha1.TrafficTarget{
-		TrafficTarget: v1.TrafficTarget{
-			RevisionName: goodOldRev.Name,
-			Percent:      ptr.Int64(100),
-		},
-	}, v1alpha1.TrafficTarget{
-		TrafficTarget: v1.TrafficTarget{
-			Tag:          "beta",
-			RevisionName: goodNewRev.Name,
-		},
-	}, v1alpha1.TrafficTarget{
-		TrafficTarget: v1.TrafficTarget{
-			Tag:               "alpha",
-			ConfigurationName: niceConfig.Name,
-		},
+	if tc, err := BuildTrafficConfiguration(configLister, revLister, testRouteWithTrafficTargets(WithSpecTraffic(v1.TrafficTarget{
+		RevisionName: goodOldRev.Name,
+		Percent:      ptr.Int64(100),
+	}, v1.TrafficTarget{
+		Tag:          "beta",
+		RevisionName: goodNewRev.Name,
+	}, v1.TrafficTarget{
+		Tag:               "alpha",
+		ConfigurationName: niceConfig.Name,
 	}))); err != nil {
 		t.Errorf("Unexpected error %v", err)
 	} else if want, got := tc, expected; !cmp.Equal(want, got, cmpOpts...) {
@@ -774,15 +738,15 @@ func TestBuildTrafficConfiguration_Preliminary(t *testing.T) {
 func TestBuildTrafficConfiguration_MissingConfig(t *testing.T) {
 	expected := &Config{
 		Targets: map[string]RevisionTargets{},
-		Configurations: map[string]*v1alpha1.Configuration{
+		Configurations: map[string]*v1.Configuration{
 			goodConfig.Name: goodConfig,
 		},
-		Revisions: map[string]*v1alpha1.Revision{
+		Revisions: map[string]*v1.Revision{
 			goodOldRev.Name: goodOldRev,
 			goodNewRev.Name: goodNewRev,
 		},
 		MissingTargets: []corev1.ObjectReference{{
-			APIVersion: "serving.knative.dev/v1alpha1",
+			APIVersion: "serving.knative.dev/v1",
 			Kind:       "Configuration",
 			Name:       missingConfig.Name,
 			Namespace:  missingConfig.Namespace,
@@ -790,21 +754,15 @@ func TestBuildTrafficConfiguration_MissingConfig(t *testing.T) {
 	}
 
 	expectedErr := errMissingConfiguration(missingConfig.Name)
-	r := testRouteWithTrafficTargets(WithSpecTraffic(v1alpha1.TrafficTarget{
-		TrafficTarget: v1.TrafficTarget{
-			RevisionName: goodOldRev.Name,
-			Percent:      ptr.Int64(100),
-		},
-	}, v1alpha1.TrafficTarget{
-		TrafficTarget: v1.TrafficTarget{
-			Tag:          "beta",
-			RevisionName: goodNewRev.Name,
-		},
-	}, v1alpha1.TrafficTarget{
-		TrafficTarget: v1.TrafficTarget{
-			Tag:               "alpha",
-			ConfigurationName: missingConfig.Name,
-		},
+	r := testRouteWithTrafficTargets(WithSpecTraffic(v1.TrafficTarget{
+		RevisionName: goodOldRev.Name,
+		Percent:      ptr.Int64(100),
+	}, v1.TrafficTarget{
+		Tag:          "beta",
+		RevisionName: goodNewRev.Name,
+	}, v1.TrafficTarget{
+		Tag:               "alpha",
+		ConfigurationName: missingConfig.Name,
 	}))
 	if tc, err := BuildTrafficConfiguration(configLister, revLister, r); err != nil && expectedErr.Error() != err.Error() {
 		t.Errorf("Expected %v, saw %v", expectedErr, err)
@@ -816,15 +774,13 @@ func TestBuildTrafficConfiguration_MissingConfig(t *testing.T) {
 func TestBuildTrafficConfiguration_NotRoutableRevision(t *testing.T) {
 	expected := &Config{
 		Targets:        map[string]RevisionTargets{},
-		Configurations: map[string]*v1alpha1.Configuration{},
-		Revisions:      map[string]*v1alpha1.Revision{unreadyRev.Name: unreadyRev},
+		Configurations: map[string]*v1.Configuration{},
+		Revisions:      map[string]*v1.Revision{unreadyRev.Name: unreadyRev},
 	}
 	expectedErr := errUnreadyRevision(unreadyRev)
-	if tc, err := BuildTrafficConfiguration(configLister, revLister, testRouteWithTrafficTargets(WithSpecTraffic(v1alpha1.TrafficTarget{
-		TrafficTarget: v1.TrafficTarget{
-			RevisionName: unreadyRev.Name,
-			Percent:      ptr.Int64(100),
-		},
+	if tc, err := BuildTrafficConfiguration(configLister, revLister, testRouteWithTrafficTargets(WithSpecTraffic(v1.TrafficTarget{
+		RevisionName: unreadyRev.Name,
+		Percent:      ptr.Int64(100),
 	}))); err != nil && expectedErr.Error() != err.Error() {
 		t.Errorf("Expected error %v, saw %v", expectedErr, err)
 	} else if got, want := tc, expected; !cmp.Equal(want, got, cmpOpts...) {
@@ -835,15 +791,13 @@ func TestBuildTrafficConfiguration_NotRoutableRevision(t *testing.T) {
 func TestBuildTrafficConfiguration_NotRoutableConfiguration(t *testing.T) {
 	expected := &Config{
 		Targets:        map[string]RevisionTargets{},
-		Configurations: map[string]*v1alpha1.Configuration{unreadyConfig.Name: unreadyConfig},
-		Revisions:      map[string]*v1alpha1.Revision{},
+		Configurations: map[string]*v1.Configuration{unreadyConfig.Name: unreadyConfig},
+		Revisions:      map[string]*v1.Revision{},
 	}
 	expectedErr := errUnreadyConfiguration(unreadyConfig)
-	if tc, err := BuildTrafficConfiguration(configLister, revLister, testRouteWithTrafficTargets(WithSpecTraffic(v1alpha1.TrafficTarget{
-		TrafficTarget: v1.TrafficTarget{
-			ConfigurationName: unreadyConfig.Name,
-			Percent:           ptr.Int64(100),
-		},
+	if tc, err := BuildTrafficConfiguration(configLister, revLister, testRouteWithTrafficTargets(WithSpecTraffic(v1.TrafficTarget{
+		ConfigurationName: unreadyConfig.Name,
+		Percent:           ptr.Int64(100),
 	}))); err != nil && expectedErr.Error() != err.Error() {
 		t.Errorf("Expected error %v, saw %v", expectedErr, err)
 	} else if got, want := tc, expected; !cmp.Equal(want, got, cmpOpts...) {
@@ -854,18 +808,16 @@ func TestBuildTrafficConfiguration_NotRoutableConfiguration(t *testing.T) {
 func TestBuildTrafficConfiguration_EmptyConfiguration(t *testing.T) {
 	expected := &Config{
 		Targets: map[string]RevisionTargets{},
-		Configurations: map[string]*v1alpha1.Configuration{
+		Configurations: map[string]*v1.Configuration{
 			emptyConfig.Name: emptyConfig,
 		},
-		Revisions: map[string]*v1alpha1.Revision{},
+		Revisions: map[string]*v1.Revision{},
 	}
 
 	expectedErr := errUnreadyConfiguration(emptyConfig)
-	if tc, err := BuildTrafficConfiguration(configLister, revLister, testRouteWithTrafficTargets(WithSpecTraffic(v1alpha1.TrafficTarget{
-		TrafficTarget: v1.TrafficTarget{
-			ConfigurationName: emptyConfig.Name,
-			Percent:           ptr.Int64(100),
-		},
+	if tc, err := BuildTrafficConfiguration(configLister, revLister, testRouteWithTrafficTargets(WithSpecTraffic(v1.TrafficTarget{
+		ConfigurationName: emptyConfig.Name,
+		Percent:           ptr.Int64(100),
 	}))); err != nil && expectedErr.Error() != err.Error() {
 		t.Errorf("Expected error %v, saw %v", expectedErr, err)
 	} else if got, want := tc, expected; !cmp.Equal(want, got, cmpOpts...) {
@@ -876,23 +828,19 @@ func TestBuildTrafficConfiguration_EmptyConfiguration(t *testing.T) {
 func TestBuildTrafficConfiguration_EmptyAndFailedConfigurations(t *testing.T) {
 	expected := &Config{
 		Targets: map[string]RevisionTargets{},
-		Configurations: map[string]*v1alpha1.Configuration{
+		Configurations: map[string]*v1.Configuration{
 			emptyConfig.Name:  emptyConfig,
 			failedConfig.Name: failedConfig,
 		},
-		Revisions: map[string]*v1alpha1.Revision{},
+		Revisions: map[string]*v1.Revision{},
 	}
 	expectedErr := errUnreadyConfiguration(failedConfig)
-	if tc, err := BuildTrafficConfiguration(configLister, revLister, testRouteWithTrafficTargets(WithSpecTraffic(v1alpha1.TrafficTarget{
-		TrafficTarget: v1.TrafficTarget{
-			ConfigurationName: emptyConfig.Name,
-			Percent:           ptr.Int64(50),
-		},
-	}, v1alpha1.TrafficTarget{
-		TrafficTarget: v1.TrafficTarget{
-			ConfigurationName: failedConfig.Name,
-			Percent:           ptr.Int64(50),
-		},
+	if tc, err := BuildTrafficConfiguration(configLister, revLister, testRouteWithTrafficTargets(WithSpecTraffic(v1.TrafficTarget{
+		ConfigurationName: emptyConfig.Name,
+		Percent:           ptr.Int64(50),
+	}, v1.TrafficTarget{
+		ConfigurationName: failedConfig.Name,
+		Percent:           ptr.Int64(50),
 	}))); err != nil && expectedErr.Error() != err.Error() {
 		t.Errorf("Expected error %v, saw %v", expectedErr, err)
 	} else if got, want := tc, expected; !cmp.Equal(want, got, cmpOpts...) {
@@ -903,23 +851,19 @@ func TestBuildTrafficConfiguration_EmptyAndFailedConfigurations(t *testing.T) {
 func TestBuildTrafficConfiguration_FailedAndEmptyConfigurations(t *testing.T) {
 	expected := &Config{
 		Targets: map[string]RevisionTargets{},
-		Configurations: map[string]*v1alpha1.Configuration{
+		Configurations: map[string]*v1.Configuration{
 			emptyConfig.Name:  emptyConfig,
 			failedConfig.Name: failedConfig,
 		},
-		Revisions: map[string]*v1alpha1.Revision{},
+		Revisions: map[string]*v1.Revision{},
 	}
 	expectedErr := errUnreadyConfiguration(failedConfig)
-	if tc, err := BuildTrafficConfiguration(configLister, revLister, testRouteWithTrafficTargets(WithSpecTraffic(v1alpha1.TrafficTarget{
-		TrafficTarget: v1.TrafficTarget{
-			ConfigurationName: failedConfig.Name,
-			Percent:           ptr.Int64(50),
-		},
-	}, v1alpha1.TrafficTarget{
-		TrafficTarget: v1.TrafficTarget{
-			ConfigurationName: emptyConfig.Name,
-			Percent:           ptr.Int64(50),
-		},
+	if tc, err := BuildTrafficConfiguration(configLister, revLister, testRouteWithTrafficTargets(WithSpecTraffic(v1.TrafficTarget{
+		ConfigurationName: failedConfig.Name,
+		Percent:           ptr.Int64(50),
+	}, v1.TrafficTarget{
+		ConfigurationName: emptyConfig.Name,
+		Percent:           ptr.Int64(50),
 	}))); err != nil && expectedErr.Error() != err.Error() {
 		t.Errorf("Expected error %v, saw %v", expectedErr, err)
 	} else if got, want := tc, expected; !cmp.Equal(want, got, cmpOpts...) {
@@ -930,26 +874,22 @@ func TestBuildTrafficConfiguration_FailedAndEmptyConfigurations(t *testing.T) {
 func TestBuildTrafficConfiguration_MissingRevision(t *testing.T) {
 	expected := &Config{
 		Targets:        map[string]RevisionTargets{},
-		Configurations: map[string]*v1alpha1.Configuration{goodConfig.Name: goodConfig},
-		Revisions:      map[string]*v1alpha1.Revision{goodNewRev.Name: goodNewRev},
+		Configurations: map[string]*v1.Configuration{goodConfig.Name: goodConfig},
+		Revisions:      map[string]*v1.Revision{goodNewRev.Name: goodNewRev},
 		MissingTargets: []corev1.ObjectReference{{
-			APIVersion: "serving.knative.dev/v1alpha1",
+			APIVersion: "serving.knative.dev/v1",
 			Kind:       "Revision",
 			Name:       missingRev.Name,
 			Namespace:  missingRev.Namespace,
 		}},
 	}
 	expectedErr := errMissingRevision(missingRev.Name)
-	if tc, err := BuildTrafficConfiguration(configLister, revLister, testRouteWithTrafficTargets(WithSpecTraffic(v1alpha1.TrafficTarget{
-		TrafficTarget: v1.TrafficTarget{
-			RevisionName: missingRev.Name,
-			Percent:      ptr.Int64(50),
-		},
-	}, v1alpha1.TrafficTarget{
-		TrafficTarget: v1.TrafficTarget{
-			RevisionName: goodNewRev.Name,
-			Percent:      ptr.Int64(50),
-		},
+	if tc, err := BuildTrafficConfiguration(configLister, revLister, testRouteWithTrafficTargets(WithSpecTraffic(v1.TrafficTarget{
+		RevisionName: missingRev.Name,
+		Percent:      ptr.Int64(50),
+	}, v1.TrafficTarget{
+		RevisionName: goodNewRev.Name,
+		Percent:      ptr.Int64(50),
 	}))); err != nil && expectedErr.Error() != err.Error() {
 		t.Errorf("Expected %s, saw %s", expectedErr.Error(), err.Error())
 	} else if got, want := tc, expected; !cmp.Equal(want, got, cmpOpts...) {
@@ -958,47 +898,35 @@ func TestBuildTrafficConfiguration_MissingRevision(t *testing.T) {
 }
 
 func TestRoundTripping(t *testing.T) {
-	expected := []v1alpha1.TrafficTarget{{
-		TrafficTarget: v1.TrafficTarget{
-			RevisionName:   goodOldRev.Name,
-			Percent:        ptr.Int64(100),
-			LatestRevision: ptr.Bool(false),
-		},
+	expected := []v1.TrafficTarget{{
+		RevisionName:   goodOldRev.Name,
+		Percent:        ptr.Int64(100),
+		LatestRevision: ptr.Bool(false),
 	}, {
-		TrafficTarget: v1.TrafficTarget{
-			Tag:            "beta",
-			RevisionName:   goodNewRev.Name,
-			URL:            domains.URL(domains.HTTPScheme, "beta-test-route.test.example.com"),
-			LatestRevision: ptr.Bool(false),
-		},
+		Tag:            "beta",
+		RevisionName:   goodNewRev.Name,
+		URL:            domains.URL(domains.HTTPScheme, "beta-test-route.test.example.com"),
+		LatestRevision: ptr.Bool(false),
 	}, {
-		TrafficTarget: v1.TrafficTarget{
-			Tag:            "alpha",
-			RevisionName:   niceNewRev.Name,
-			URL:            domains.URL(domains.HTTPScheme, "alpha-test-route.test.example.com"),
-			LatestRevision: ptr.Bool(true),
-		},
+		Tag:            "alpha",
+		RevisionName:   niceNewRev.Name,
+		URL:            domains.URL(domains.HTTPScheme, "alpha-test-route.test.example.com"),
+		LatestRevision: ptr.Bool(true),
 	}}
-	route := testRouteWithTrafficTargets(WithSpecTraffic(v1alpha1.TrafficTarget{
-		TrafficTarget: v1.TrafficTarget{
-			RevisionName: goodOldRev.Name,
-			Percent:      ptr.Int64(100),
-		},
-	}, v1alpha1.TrafficTarget{
-		TrafficTarget: v1.TrafficTarget{
-			Tag:          "beta",
-			RevisionName: goodNewRev.Name,
-		},
-	}, v1alpha1.TrafficTarget{
-		TrafficTarget: v1.TrafficTarget{
-			Tag:               "alpha",
-			ConfigurationName: niceConfig.Name,
-		},
+	route := testRouteWithTrafficTargets(WithSpecTraffic(v1.TrafficTarget{
+		RevisionName: goodOldRev.Name,
+		Percent:      ptr.Int64(100),
+	}, v1.TrafficTarget{
+		Tag:          "beta",
+		RevisionName: goodNewRev.Name,
+	}, v1.TrafficTarget{
+		Tag:               "alpha",
+		ConfigurationName: niceConfig.Name,
 	}))
 	if tc, err := BuildTrafficConfiguration(configLister, revLister, route); err != nil {
 		t.Errorf("Unexpected error %v", err)
 	} else {
-		targets, err := tc.GetRevisionTrafficTargets(getContext(), route, sets.String{})
+		targets, err := tc.GetRevisionTrafficTargets(getContext(), route)
 		if err != nil {
 			t.Errorf("Unexpected error %v", err)
 		}
@@ -1008,21 +936,19 @@ func TestRoundTripping(t *testing.T) {
 	}
 }
 
-func testConfig(name string) *v1alpha1.Configuration {
-	return &v1alpha1.Configuration{
+func testConfig(name string) *v1.Configuration {
+	return &v1.Configuration{
 		ObjectMeta: metav1.ObjectMeta{
 			Name:      name,
 			Namespace: testNamespace,
 		},
-		Spec: v1alpha1.ConfigurationSpec{
-			Template: &v1alpha1.RevisionTemplateSpec{
-				Spec: v1alpha1.RevisionSpec{
-					RevisionSpec: v1.RevisionSpec{
-						PodSpec: corev1.PodSpec{
-							Containers: []corev1.Container{{
-								Image: "test-image",
-							}},
-						},
+		Spec: v1.ConfigurationSpec{
+			Template: v1.RevisionTemplateSpec{
+				Spec: v1.RevisionSpec{
+					PodSpec: corev1.PodSpec{
+						Containers: []corev1.Container{{
+							Image: "test-image",
+						}},
 					},
 				},
 			},
@@ -1030,8 +956,8 @@ func testConfig(name string) *v1alpha1.Configuration {
 	}
 }
 
-func testRevForConfig(config *v1alpha1.Configuration, name string) *v1alpha1.Revision {
-	return &v1alpha1.Revision{
+func testRevForConfig(config *v1.Configuration, name string) *v1.Revision {
+	return &v1.Revision{
 		ObjectMeta: metav1.ObjectMeta{
 			Name:      name,
 			Namespace: testNamespace,
@@ -1043,13 +969,13 @@ func testRevForConfig(config *v1alpha1.Configuration, name string) *v1alpha1.Rev
 	}
 }
 
-func getTestEmptyConfig(name string) *v1alpha1.Configuration {
+func getTestEmptyConfig(name string) *v1.Configuration {
 	config := testConfig(name + "-config")
 	config.Status.InitializeConditions()
 	return config
 }
 
-func testConfigWithDeletedRevision(name string) *v1alpha1.Configuration {
+func testConfigWithDeletedRevision(name string) *v1.Configuration {
 	config := testConfig(name + "-config")
 	config.Status.SetLatestCreatedRevisionName("i-was-deleted")
 	config.Status.SetLatestReadyRevisionName("")
@@ -1057,23 +983,23 @@ func testConfigWithDeletedRevision(name string) *v1alpha1.Configuration {
 	return config
 }
 
-func getTestUnreadyConfig(name string) (*v1alpha1.Configuration, *v1alpha1.Revision) {
+func getTestUnreadyConfig(name string) (*v1.Configuration, *v1.Revision) {
 	config := testConfig(name + "-config")
 	rev := testRevForConfig(config, name+"-revision")
 	config.Status.SetLatestCreatedRevisionName(rev.Name)
 	return config, rev
 }
 
-func getTestFailedConfig(name string) (*v1alpha1.Configuration, *v1alpha1.Revision) {
+func getTestFailedConfig(name string) (*v1.Configuration, *v1.Revision) {
 	config := testConfig(name + "-config")
 	rev := testRevForConfig(config, name+"-revision")
 	config.Status.SetLatestCreatedRevisionName(rev.Name)
 	config.Status.MarkLatestCreatedFailed(rev.Name, "Permanently failed")
-	rev.Status.MarkContainerHealthyFalse(v1alpha1.ContainerMissing, "Should have used ko")
+	rev.Status.MarkContainerHealthyFalse(v1.ReasonContainerMissing, "Should have used ko")
 	return config, rev
 }
 
-func getTestInactiveConfig(name string) (*v1alpha1.Configuration, *v1alpha1.Revision) {
+func getTestInactiveConfig(name string) (*v1.Configuration, *v1.Revision) {
 	config := testConfig(name + "-config")
 	rev := testRevForConfig(config, name+"-revision")
 	config.Status.SetLatestReadyRevisionName(rev.Name)
@@ -1083,7 +1009,7 @@ func getTestInactiveConfig(name string) (*v1alpha1.Configuration, *v1alpha1.Revi
 	return config, rev
 }
 
-func getTestReadyConfig(name string) (*v1alpha1.Configuration, *v1alpha1.Revision, *v1alpha1.Revision) {
+func getTestReadyConfig(name string) (*v1.Configuration, *v1.Revision, *v1.Revision) {
 	config := testConfig(name + "-config")
 	rev1 := testRevForConfig(config, name+"-revision-1")
 	rev1.Status.MarkResourcesAvailableTrue()
